package sun.net.www.protocol.http;

import sun.util.logging.PlatformLogger;
import java.net.PasswordAuthentication;
import java.net.URL;
import java.lang.reflect.Constructor;
import java.lang.reflect.Method;

class NTLMAuthenticationProxy
{
    private static Method supportsTA;
    private static Method isTrustedSite;
    private static final String clazzStr = "sun.net.www.protocol.http.ntlm.NTLMAuthentication";
    private static final String supportsTAStr = "supportsTransparentAuth";
    private static final String isTrustedSiteStr = "isTrustedSite";
    static final NTLMAuthenticationProxy proxy;
    static final boolean supported;
    static final boolean supportsTransparentAuth;
    private final Constructor<? extends AuthenticationInfo> threeArgCtr;
    private final Constructor<? extends AuthenticationInfo> fiveArgCtr;
    
    private NTLMAuthenticationProxy(Constructor<? extends AuthenticationInfo> threeArgCtr, Constructor<? extends AuthenticationInfo> fiveArgCtr) {
        this.threeArgCtr = threeArgCtr;
        this.fiveArgCtr = fiveArgCtr;
    }
    
    AuthenticationInfo create(boolean b, URL url, PasswordAuthentication passwordAuthentication) {
        try {
            return (AuthenticationInfo)this.threeArgCtr.newInstance(new Object[] { Boolean.valueOf(b), url, passwordAuthentication });
        }
        catch (ReflectiveOperationException ex) {
            finest(ex);
            return null;
        }
    }
    
    AuthenticationInfo create(boolean b, String s, int i, PasswordAuthentication passwordAuthentication) {
        try {
            return (AuthenticationInfo)this.fiveArgCtr.newInstance(new Object[] { Boolean.valueOf(b), s, Integer.valueOf(i), passwordAuthentication });
        }
        catch (ReflectiveOperationException ex) {
            finest(ex);
            return null;
        }
    }
    
    private static boolean supportsTransparentAuth() {
        try {
            return (boolean)NTLMAuthenticationProxy.supportsTA.invoke(null, new Object[0]);
        }
        catch (ReflectiveOperationException ex) {
            finest(ex);
            return false;
        }
    }
    
    public static boolean isTrustedSite(URL url) {
        try {
            return (boolean)NTLMAuthenticationProxy.isTrustedSite.invoke(null, new Object[] { url });
        }
        catch (ReflectiveOperationException ex) {
            finest(ex);
            return false;
        }
    }
    
    private static NTLMAuthenticationProxy tryLoadNTLMAuthentication() {
        try {
            Class<Object> forName = Class.forName("sun.net.www.protocol.http.ntlm.NTLMAuthentication", true, null);
            if (forName != null) {
                Constructor<Object> constructor = forName.getConstructor(new Class[] { Boolean.TYPE, URL.class, PasswordAuthentication.class });
                Constructor<Object> constructor2 = forName.getConstructor(new Class[] { Boolean.TYPE, String.class, Integer.TYPE, PasswordAuthentication.class });
                NTLMAuthenticationProxy.supportsTA = forName.getDeclaredMethod("supportsTransparentAuth", new Class[0]);
                NTLMAuthenticationProxy.isTrustedSite = forName.getDeclaredMethod("isTrustedSite", new Class[] { URL.class });
                return new NTLMAuthenticationProxy(constructor, constructor2);
            }
        }
        catch (ClassNotFoundException ex) {
            finest(ex);
        }
        catch (ReflectiveOperationException detailMessage) {
            throw new AssertionError(detailMessage);
        }
        return null;
    }
    
    static void finest(Exception obj) {
        PlatformLogger httpLogger = HttpURLConnection.getHttpLogger();
        if (httpLogger.isLoggable(PlatformLogger.Level.FINEST)) {
            httpLogger.finest("NTLMAuthenticationProxy: " + obj);
        }
    }
    
    static {
        proxy = tryLoadNTLMAuthentication();
        supported = (NTLMAuthenticationProxy.proxy != null);
        supportsTransparentAuth = (NTLMAuthenticationProxy.supported && supportsTransparentAuth());
    }
}
